## Build dist
```shell
python setup.py sdist
```

## Upload to pypi
```shell
twine upload dist/*
```
#### Username
```
kaliiiiiiiiii
```

## Install on version from pypi

#### python3.7.9

```shell
C:\Users\aurin\PycharmProjects\selenium_profiles\venv\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```
#### python3.8

```shell
C:\Users\aurin\PycharmProjects\selenium_profiles\venv38\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```
#### python3.9

```shell
C:\Users\aurin\PycharmProjects\selenium_profiles\venv39\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```
#### python3.10

```shell
C:\Users\aurin\PycharmProjects\selenium_profiles\venv310\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```
#### python3.11

```shell
C:\Users\aurin\PycharmProjects\selenium_profiles\venv311\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```